from sparrow.api import create_app

__all__ = ["create_application"]


def create_application():
    app = create_app(
        title="vector_search",
        version="1.0",
    )

    app.add_exception_handler()
    return app



from fastapi import APIRouter

router = APIRouter()


@router.get("/")
async def root():
    return {"message": "Hello World"}


@router.get("/hello/{name}")
async def say_hello(name: str):
    return {"message": f"Hello {name}"}
